using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using System.Reflection;

namespace Raft
{
	public class Raft_FishAI : MonoBehaviour
	{
		public static List<Raft_FishAI> Fishes = new List<Raft_FishAI>();
		public Rigidbody2D Rb;
		private PhysicalBehaviour PB;
		private SpriteRenderer Renderer;
		private float Speed = 250;


		public int flipMultiplier
		{
			get
			{
				return Renderer.flipX ? -1 : 1;
			}
		}

		public Vector2 StartPos;
		public Vector2 TargetOffset;

		public float HP = 10;
		public bool IsDead => HP <= 0;

		private void Start()
		{
			StartPos = transform.position;
			Rb = gameObject.GetComponent<Rigidbody2D>();
			Renderer = gameObject.GetComponent<SpriteRenderer>();
			PB = gameObject.GetComponent<PhysicalBehaviour>();
			Rb.freezeRotation = true;

			foreach (Raft_FishAI fish in Fishes)
			{
				if(fish) Physics2D.IgnoreCollision(GetComponent<Collider2D>(), fish.GetComponent<Collider2D>());
			}
			Fishes.Add(this);
		}

		private void FixedUpdate()
		{
            if (IsDead)
            {
				Renderer.flipY = true;
				Rb.freezeRotation = false;
				return;
            }

			if (Rb.velocity.x < 0)
			{
				Renderer.flipX = false;
			}
			if (Rb.velocity.x > 0)
			{
				Renderer.flipX = true;
			}

			if(System.Math.Round(Vector2.Distance(StartPos + TargetOffset, transform.position), 1) < 1)
            {
				TargetOffset = Random.insideUnitCircle * 5;
				if ((StartPos + TargetOffset).y > -1) TargetOffset.y = -1 - StartPos.y;
            }
            else
            {
				Vector2 force = (StartPos + TargetOffset) - (Vector2)transform.position;
				force.y *= 10 * Mathf.Clamp(Mathf.Abs(transform.position.y)/5,1,float.MaxValue);
				force.x *= 7;
				force *= (PB.IsUnderWater ? 1 : 0);
				Rb.AddForce(force);
			}
			if (Rb.velocity.magnitude < 0.01) Rb.velocity *= 10;

			if (!PB.IsUnderWater) HP -= 2 * Time.deltaTime;
			else if (!IsDead) HP = 15;

			if (Vector2.Distance((Vector2)transform.position, StartPos) > 10) StartPos = transform.position;
		}

		private void Update()
		{

		}

		private void OnCollisionEnter2D(Collision2D collision)
		{
			if (!PB.IsUnderWater && !IsDead)
			{
				Vector2 Force = Random.insideUnitCircle * 250;
				if (Force.y < 0) Force.y *= -1;
				Rb.AddForce(Force);
			}
		}

		private void OnDestroy()
        {
			Fishes.Remove(this);
        }
	}
}