using UnityEngine;
using UnityEngine.UI;
using Raft;
using System.Collections;
using System.Collections.Generic;
using System.Reflection;

namespace Raft
{
    public class Raft_Main
    {
        public static Sprite[] Fishes = new Sprite[0];

        public static void Main()
        {
            Fishes = new Sprite[]
            {
                ModAPI.LoadSprite("Sprites/Fishes/Clowfish.png"),
                ModAPI.LoadSprite("Sprites/Fishes/Murmu Fish.png"),
                ModAPI.LoadSprite("Sprites/Fishes/Qvc Fish.png"),
                ModAPI.LoadSprite("Sprites/Fishes/Toxic Fish.png"),
                ModAPI.LoadSprite("Sprites/Fishes/Cod.png"),
                ModAPI.LoadSprite("Sprites/Fishes/Pufferfish.png"),
                ModAPI.LoadSprite("Sprites/Fishes/Salmon.png")
            };

            ModAPI.Register(
            new Modification()
            {
                OriginalItem = ModAPI.FindSpawnable("Brick"),
                NameOverride = "Fish",
                DescriptionOverride = "A robot stylized as a fish. Imitates real fish: Swims, can shut down on the surface.",
                CategoryOverride = ModAPI.FindCategory("Entities"),
                ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Thumb.png"),
                AfterSpawn = (Instance) =>
                {
                    Instance.GetComponent<SpriteRenderer>().sprite = Fishes[UnityEngine.Random.Range(0, Fishes.Length)];

                    PhysicalBehaviour phys = Instance.GetComponent<PhysicalBehaviour>();
                    phys.Properties = ModAPI.FindPhysicalProperties("Human");
                    phys.InitialMass = 1;
                    phys.TrueInitialMass = 1;

                    Instance.AddComponent<Raft_FishAI>();
                }
            });

            ModAPI.Register(
                    new Modification()
                    {
                        OriginalItem = ModAPI.FindSpawnable("Plastic Barrel"),
                        NameOverride = "Barrel",
                        NameToOrderByOverride = "bFm",
                        DescriptionOverride = "Put anything you want inside that barrel. But a fish is bette",
                        CategoryOverride = ModAPI.FindCategory("Misc."),
                        ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Barrel.png"),
                        AfterSpawn = (Instance) =>
                        {
                            Instance.GetComponent<SpriteRenderer>().sortingLayerName = "Botom";
                            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/BarrelCOL.png", 9.0f);
                            foreach (var ColliderBoxDeleteVar in Instance.GetComponents<Collider2D>())
                            {
                                GameObject.Destroy(ColliderBoxDeleteVar);
                            }
                            Instance.FixColliders();
                            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/Barrel.png", 0.9f);
                            var phys = Instance.GetComponent<PhysicalBehaviour>();
                            var prop = ModAPI.FindPhysicalProperties("Wood");
                        }
                    }
                );

                ModAPI.Register(
                    new Modification()
                    {
                        OriginalItem = ModAPI.FindSpawnable("Wooden Pole"),
                        NameOverride = "Wooden Pier",
                        NameToOrderByOverride = "bFm",
                        DescriptionOverride = "Pier. You can walk, run, kill, and even jump from it into the water",
                        CategoryOverride = ModAPI.FindCategory("Misc."),
                        ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Wooden Pierce.png"),
                        AfterSpawn = (Instance) =>
                        {
                            Instance.GetComponent<SpriteRenderer>().sortingLayerName = "Botom";
                            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/Wooden Pierce 2COL.png", 9.0f);
                            foreach (var ColliderBoxDeleteVar in Instance.GetComponents<Collider2D>())
                            {
                                GameObject.Destroy(ColliderBoxDeleteVar);
                            }
                            Instance.FixColliders();
                            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/Wooden Pierce 2.png", 0.9f);
                            var phys = Instance.GetComponent<PhysicalBehaviour>();
                            var prop = ModAPI.FindPhysicalProperties("Wood");
                        }
                    }
                );

                ModAPI.Register(
                    new Modification()
                    {
                        OriginalItem = ModAPI.FindSpawnable("Wooden Pole"),
                        NameOverride = "Wooden Pier Beams",
                        NameToOrderByOverride = "bFm",
                        DescriptionOverride = "To increase the size of Pier's supports",
                        CategoryOverride = ModAPI.FindCategory("Misc."),
                        ThumbnailOverride = ModAPI.LoadSprite("Thumbnail/Pierce Pipes.png"),
                        AfterSpawn = (Instance) =>
                        {
                            Instance.GetComponent<SpriteRenderer>().sortingLayerName = "Botom";
                            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/Pierce PipesCOL.png", 9.0f);
                            foreach (var ColliderBoxDeleteVar in Instance.GetComponents<Collider2D>())
                            {
                                GameObject.Destroy(ColliderBoxDeleteVar);
                            }
                            Instance.FixColliders();
                            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Sprites/Pierce Pipes.png", 0.9f);
                            var phys = Instance.GetComponent<PhysicalBehaviour>();
                            var prop = ModAPI.FindPhysicalProperties("Wood");
                        }
                    }
                );

            ModAPI.Register<FishSpawner>();
        }
    }

    public class FishSpawner : MonoBehaviour
    {
        private void Start()
        {
            if (MapLoaderBehaviour.CurrentMap.name != "Sea")
            {
                Debug.Log("Wrong map");
                return;
            }

            for (int i = 0; i < UnityEngine.Random.Range(175, 200); i++)
            {
                SpawnCatalagObject("Fish").transform.position = GameObject.Find("Sea").transform.position + new Vector3(UnityEngine.Random.Range(-250, 250), UnityEngine.Random.Range(50, -50));
            }
        }

        private GameObject SpawnCatalagObject(string Item)
        {
            SpawnableAsset AssetItem = ModAPI.FindSpawnable(Item);
            GameObject SpawnedItem = UnityEngine.Object.Instantiate(ModAPI.FindSpawnable(Item).Prefab);
            CatalogBehaviour.PerformMod(AssetItem, SpawnedItem);
            return SpawnedItem;
        }
    }
}